@@ -18,7 +18,7 @@ build_time_vars = {'ABIFLAGS': '',
               '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'mips64--netbsd',
+ 'BUILD_GNU_TYPE': 'sparc--netbsdelf',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
@@ -43,21 +43,21 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-expat' "
                 "'--with-system-ffi' '--without-ensurepip' "
                 "'--without-pymalloc' '--prefix=/usr/pkg' "
-                "'--build=mips64--netbsd' '--host=mips64--netbsd' "
+                "'--build=sparc--netbsdelf' '--host=sparc--netbsdelf' "
                 "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
-                "'build_alias=mips64--netbsd' 'host_alias=mips64--netbsd' "
+                "'build_alias=sparc--netbsdelf' 'host_alias=sparc--netbsdelf' "
                 "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
                 "'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
                 "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
                 "'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' "
-                "'PKG_CONFIG=/tmp/pkgbuild/lang/python38/work.mips64eb/.tools/bin/pkg-config' "
+                "'PKG_CONFIG=/tmp/pkgbuild/lang/python38/work.sparc/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python38/work.mips64eb/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python38/work.mips64eb/.buildlink/share/pkgconfig'",
+                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python38/work.sparc/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python38/work.sparc/.buildlink/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python38/work.mips64eb/Python-3.8.19/coverage.info',
- 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python38/work.mips64eb/Python-3.8.19/lcov-report',
+ 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20/coverage.info',
+ 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
@@ -219,7 +219,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -525,7 +525,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'mips64--netbsd',
+ 'HOST_GNU_TYPE': 'sparc--netbsdelf',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.8 /usr/pkg/include/python3.8',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -701,7 +701,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python38/work.mips64eb/Python-3.8.19',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '@SGI_ABI@',
@@ -716,7 +716,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 16,
+ 'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
@@ -743,10 +743,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python38/work.mips64eb/Python-3.8.19 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python38/work.mips64eb/Python-3.8.19 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -768,8 +768,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/tmp/pkgbuild/lang/python38/work.mips64eb/Python-3.8.19',
- 'abs_srcdir': '/tmp/pkgbuild/lang/python38/work.mips64eb/Python-3.8.19',
+ 'abs_builddir': '/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20',
+ 'abs_srcdir': '/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
