@@ -5,6 +5,7 @@
 # Copyright (c) 2003-2005 by Peter Astrand <astrand@lysator.liu.se>
 #
 # Licensed to PSF under a Contributor Agreement.
+# See http://www.python.org/2.4/license for licensing details.
 
 r"""Subprocesses with accessible I/O streams
 
@@ -51,12 +52,6 @@ import threading
 import warnings
 import contextlib
 from time import monotonic as _time
-import types
-
-try:
-    import fcntl
-except ImportError:
-    fcntl = None
 
 
 __all__ = ["Popen", "PIPE", "STDOUT", "call", "check_call", "getstatusoutput",
@@ -322,7 +317,7 @@ def _args_from_interpreter_flags():
     if dev_mode:
         args.extend(('-X', 'dev'))
     for opt in ('faulthandler', 'tracemalloc', 'importtime',
-                'showrefcount', 'utf8'):
+                'showalloccount', 'showrefcount', 'utf8'):
         if opt in xoptions:
             value = xoptions[opt]
             if value is True:
@@ -411,8 +406,7 @@ def check_output(*popenargs, timeout=None, **kwargs):
     if 'input' in kwargs and kwargs['input'] is None:
         # Explicitly passing input=None was previously equivalent to passing an
         # empty string. That is maintained here for backwards compatibility.
-        if kwargs.get('universal_newlines') or kwargs.get('text') or kwargs.get('encoding') \
-                or kwargs.get('errors'):
+        if kwargs.get('universal_newlines') or kwargs.get('text'):
             empty = ''
         else:
             empty = b''
@@ -448,9 +442,6 @@ class CompletedProcess(object):
             args.append('stderr={!r}'.format(self.stderr))
         return "{}({})".format(type(self).__name__, ', '.join(args))
 
-    __class_getitem__ = classmethod(types.GenericAlias)
-
-
     def check_returncode(self):
         """Raise CalledProcessError if the exit code is non-zero."""
         if self.returncode:
@@ -464,8 +455,7 @@ def run(*popenargs,
 
     The returned instance will have attributes args, returncode, stdout and
     stderr. By default, stdout and stderr are not captured, and those attributes
-    will be None. Pass stdout=PIPE and/or stderr=PIPE in order to capture them,
-    or pass capture_output=True to capture both.
+    will be None. Pass stdout=PIPE and/or stderr=PIPE in order to capture them.
 
     If check is True and the exit code was non-zero, it raises a
     CalledProcessError. The CalledProcessError object will have the return code
@@ -662,9 +652,8 @@ def _use_posix_spawn():
         # os.posix_spawn() is not available
         return False
 
-    if sys.platform in ('darwin', 'sunos5'):
-        # posix_spawn() is a syscall on both macOS and Solaris,
-        # and properly reports errors
+    if sys.platform == 'darwin':
+        # posix_spawn() is a syscall on macOS and properly reports errors
         return True
 
     # Check libc name and runtime libc version
@@ -693,13 +682,10 @@ def _use_posix_spawn():
     return False
 
 
-# These are primarily fail-safe knobs for negatives. A True value does not
-# guarantee the given libc/syscall API will be used.
 _USE_POSIX_SPAWN = _use_posix_spawn()
-_USE_VFORK = True
 
 
-class Popen:
+class Popen(object):
     """ Execute a child program in a new process.
 
     For a complete description of the arguments see the Python documentation.
@@ -737,14 +723,6 @@ class Popen:
 
       start_new_session (POSIX only)
 
-      group (POSIX only)
-
-      extra_groups (POSIX only)
-
-      user (POSIX only)
-
-      umask (POSIX only)
-
       pass_fds (POSIX only)
 
       encoding and errors: Text mode encoding and error handling to use for
@@ -761,8 +739,7 @@ class Popen:
                  shell=False, cwd=None, env=None, universal_newlines=None,
                  startupinfo=None, creationflags=0,
                  restore_signals=True, start_new_session=False,
-                 pass_fds=(), *, user=None, group=None, extra_groups=None,
-                 encoding=None, errors=None, text=None, umask=-1, pipesize=-1):
+                 pass_fds=(), *, encoding=None, errors=None, text=None):
         """Create new Popen instance."""
         _cleanup()
         # Held while anything is calling waitpid before returncode has been
@@ -779,11 +756,6 @@ class Popen:
         if not isinstance(bufsize, int):
             raise TypeError("bufsize must be an integer")
 
-        if pipesize is None:
-            pipesize = -1  # Restore default
-        if not isinstance(pipesize, int):
-            raise TypeError("pipesize must be an integer")
-
         if _mswindows:
             if preexec_fn is not None:
                 raise ValueError("preexec_fn is not supported on Windows "
@@ -808,7 +780,6 @@ class Popen:
         self.returncode = None
         self.encoding = encoding
         self.errors = errors
-        self.pipesize = pipesize
 
         # Validate the combinations of text and universal_newlines
         if (text is not None and universal_newlines is not None
@@ -850,13 +821,6 @@ class Popen:
 
         self.text_mode = encoding or errors or text or universal_newlines
 
-        # PEP 597: We suppress the EncodingWarning in subprocess module
-        # for now (at Python 3.10), because we focus on files for now.
-        # This will be changed to encoding = io.text_encoding(encoding)
-        # in the future.
-        if self.text_mode and encoding is None:
-            self.encoding = encoding = "locale"
-
         # How long to resume waiting on a child after the first ^C.
         # There is no right value for this.  The purpose is to be polite
         # yet remain good for interactive users trying to exit a tool.
@@ -873,83 +837,6 @@ class Popen:
             else:
                 line_buffering = False
 
-        gid = None
-        if group is not None:
-            if not hasattr(os, 'setregid'):
-                raise ValueError("The 'group' parameter is not supported on the "
-                                 "current platform")
-
-            elif isinstance(group, str):
-                try:
-                    import grp
-                except ImportError:
-                    raise ValueError("The group parameter cannot be a string "
-                                     "on systems without the grp module")
-
-                gid = grp.getgrnam(group).gr_gid
-            elif isinstance(group, int):
-                gid = group
-            else:
-                raise TypeError("Group must be a string or an integer, not {}"
-                                .format(type(group)))
-
-            if gid < 0:
-                raise ValueError(f"Group ID cannot be negative, got {gid}")
-
-        gids = None
-        if extra_groups is not None:
-            if not hasattr(os, 'setgroups'):
-                raise ValueError("The 'extra_groups' parameter is not "
-                                 "supported on the current platform")
-
-            elif isinstance(extra_groups, str):
-                raise ValueError("Groups must be a list, not a string")
-
-            gids = []
-            for extra_group in extra_groups:
-                if isinstance(extra_group, str):
-                    try:
-                        import grp
-                    except ImportError:
-                        raise ValueError("Items in extra_groups cannot be "
-                                         "strings on systems without the "
-                                         "grp module")
-
-                    gids.append(grp.getgrnam(extra_group).gr_gid)
-                elif isinstance(extra_group, int):
-                    gids.append(extra_group)
-                else:
-                    raise TypeError("Items in extra_groups must be a string "
-                                    "or integer, not {}"
-                                    .format(type(extra_group)))
-
-            # make sure that the gids are all positive here so we can do less
-            # checking in the C code
-            for gid_check in gids:
-                if gid_check < 0:
-                    raise ValueError(f"Group ID cannot be negative, got {gid_check}")
-
-        uid = None
-        if user is not None:
-            if not hasattr(os, 'setreuid'):
-                raise ValueError("The 'user' parameter is not supported on "
-                                 "the current platform")
-
-            elif isinstance(user, str):
-                try:
-                    import pwd
-                except ImportError:
-                    raise ValueError("The user parameter cannot be a string "
-                                     "on systems without the pwd module")
-                uid = pwd.getpwnam(user).pw_uid
-            elif isinstance(user, int):
-                uid = user
-            else:
-                raise TypeError("User must be a string or an integer")
-
-            if uid < 0:
-                raise ValueError(f"User ID cannot be negative, got {uid}")
-
         try:
             if p2cwrite != -1:
                 self.stdin = io.open(p2cwrite, 'wb', bufsize)
@@ -974,9 +861,7 @@ class Popen:
                                 p2cread, p2cwrite,
                                 c2pread, c2pwrite,
                                 errread, errwrite,
-                                restore_signals,
-                                gid, gids, uid, umask,
-                                start_new_session)
+                                restore_signals, start_new_session)
         except:
             # Cleanup if the child failed starting.
             for f in filter(None, (self.stdin, self.stdout, self.stderr)):
@@ -1006,17 +891,6 @@ class Popen:
 
             raise
 
-    def __repr__(self):
-        obj_repr = (
-            f"<{self.__class__.__name__}: "
-            f"returncode: {self.returncode} args: {self.args!r}>"
-        )
-        if len(obj_repr) > 80:
-            obj_repr = obj_repr[:76] + "...>"
-        return obj_repr
-
-    __class_getitem__ = classmethod(types.GenericAlias)
-
     @property
     def universal_newlines(self):
         # universal_newlines as retained as an alias of text_mode for API
@@ -1357,10 +1231,7 @@ class Popen:
                            p2cread, p2cwrite,
                            c2pread, c2pwrite,
                            errread, errwrite,
-                           unused_restore_signals,
-                           unused_gid, unused_gids, unused_uid,
-                           unused_umask,
-                           unused_start_new_session):
+                           unused_restore_signals, unused_start_new_session):
             """Execute program (MS Windows version)"""
 
             assert not pass_fds, "pass_fds not supported on Windows."
@@ -1427,7 +1298,23 @@ class Popen:
             if shell:
                 startupinfo.dwFlags |= _winapi.STARTF_USESHOWWINDOW
                 startupinfo.wShowWindow = _winapi.SW_HIDE
-                comspec = os.environ.get("COMSPEC", "cmd.exe")
+                if not executable:
+                    # gh-101283: without a fully-qualified path, before Windows
+                    # checks the system directories, it first looks in the
+                    # application directory, and also the current directory if
+                    # NeedCurrentDirectoryForExePathW(ExeName) is true, so try
+                    # to avoid executing unqualified "cmd.exe".
+                    comspec = os.environ.get('ComSpec')
+                    if not comspec:
+                        system_root = os.environ.get('SystemRoot', '')
+                        comspec = os.path.join(system_root, 'System32', 'cmd.exe')
+                        if not os.path.isabs(comspec):
+                            raise FileNotFoundError('shell not found: neither %ComSpec% nor %SystemRoot% is set')
+                    if os.path.isabs(comspec):
+                        executable = comspec
+                else:
+                    comspec = executable
+
                 args = '{} /c "{}"'.format (comspec, args)
 
             if cwd is not None:
@@ -1597,8 +1484,6 @@ class Popen:
                 pass
             elif stdin == PIPE:
                 p2cread, p2cwrite = os.pipe()
-                if self.pipesize > 0 and hasattr(fcntl, "F_SETPIPE_SZ"):
-                    fcntl.fcntl(p2cwrite, fcntl.F_SETPIPE_SZ, self.pipesize)
             elif stdin == DEVNULL:
                 p2cread = self._get_devnull()
             elif isinstance(stdin, int):
@@ -1611,8 +1496,6 @@ class Popen:
                 pass
             elif stdout == PIPE:
                 c2pread, c2pwrite = os.pipe()
-                if self.pipesize > 0 and hasattr(fcntl, "F_SETPIPE_SZ"):
-                    fcntl.fcntl(c2pwrite, fcntl.F_SETPIPE_SZ, self.pipesize)
             elif stdout == DEVNULL:
                 c2pwrite = self._get_devnull()
             elif isinstance(stdout, int):
@@ -1625,8 +1508,6 @@ class Popen:
                 pass
             elif stderr == PIPE:
                 errread, errwrite = os.pipe()
-                if self.pipesize > 0 and hasattr(fcntl, "F_SETPIPE_SZ"):
-                    fcntl.fcntl(errwrite, fcntl.F_SETPIPE_SZ, self.pipesize)
             elif stderr == STDOUT:
                 if c2pwrite != -1:
                     errwrite = c2pwrite
@@ -1690,9 +1571,7 @@ class Popen:
                            p2cread, p2cwrite,
                            c2pread, c2pwrite,
                            errread, errwrite,
-                           restore_signals,
-                           gid, gids, uid, umask,
-                           start_new_session):
+                           restore_signals, start_new_session):
             """Execute program (POSIX version)"""
 
             if isinstance(args, (str, bytes)):
@@ -1727,11 +1606,7 @@ class Popen:
                     and (p2cread == -1 or p2cread > 2)
                     and (c2pwrite == -1 or c2pwrite > 2)
                     and (errwrite == -1 or errwrite > 2)
-                    and not start_new_session
-                    and gid is None
-                    and gids is None
-                    and uid is None
-                    and umask < 0):
+                    and not start_new_session):
                 self._posix_spawn(args, executable, env, restore_signals,
                                   p2cread, p2cwrite,
                                   c2pread, c2pwrite,
@@ -1784,9 +1659,7 @@ class Popen:
                             p2cread, p2cwrite, c2pread, c2pwrite,
                             errread, errwrite,
                             errpipe_read, errpipe_write,
-                            restore_signals, start_new_session,
-                            gid, gids, uid, umask,
-                            preexec_fn)
+                            restore_signals, start_new_session, preexec_fn)
                     self._child_created = True
                 finally:
                     # be sure the FD is closed no matter what
@@ -1848,17 +1721,23 @@ class Popen:
                 raise child_exception_type(err_msg)
 
 
-        def _handle_exitstatus(self, sts,
-                               waitstatus_to_exitcode=os.waitstatus_to_exitcode,
-                               _WIFSTOPPED=os.WIFSTOPPED,
-                               _WSTOPSIG=os.WSTOPSIG):
+        def _handle_exitstatus(self, sts, _WIFSIGNALED=os.WIFSIGNALED,
+                _WTERMSIG=os.WTERMSIG, _WIFEXITED=os.WIFEXITED,
+                _WEXITSTATUS=os.WEXITSTATUS, _WIFSTOPPED=os.WIFSTOPPED,
+                _WSTOPSIG=os.WSTOPSIG):
             """All callers to this function MUST hold self._waitpid_lock."""
             # This method is called (indirectly) by __del__, so it cannot
             # refer to anything outside of its local scope.
-            if _WIFSTOPPED(sts):
+            if _WIFSIGNALED(sts):
+                self.returncode = -_WTERMSIG(sts)
+            elif _WIFEXITED(sts):
+                self.returncode = _WEXITSTATUS(sts)
+            elif _WIFSTOPPED(sts):
                 self.returncode = -_WSTOPSIG(sts)
             else:
-                self.returncode = waitstatus_to_exitcode(sts)
+                # Should never happen
+                raise SubprocessError("Unknown child exit status!")
+
 
         def _internal_poll(self, _deadstate=None, _waitpid=os.waitpid,
                 _WNOHANG=os.WNOHANG, _ECHILD=errno.ECHILD):
@@ -2065,35 +1944,9 @@ class Popen:
 
         def send_signal(self, sig):
             """Send a signal to the process."""
-            # bpo-38630: Polling reduces the risk of sending a signal to the
-            # wrong process if the process completed, the Popen.returncode
-            # attribute is still None, and the pid has been reassigned
-            # (recycled) to a new different process. This race condition can
-            # happens in two cases.
-            #
-            # Case 1. Thread A calls Popen.poll(), thread B calls
-            # Popen.send_signal(). In thread A, waitpid() succeed and returns
-            # the exit status. Thread B calls kill() because poll() in thread A
-            # did not set returncode yet. Calling poll() in thread B prevents
-            # the race condition thanks to Popen._waitpid_lock.
-            #
-            # Case 2. waitpid(pid, 0) has been called directly, without
-            # using Popen methods: returncode is still None is this case.
-            # Calling Popen.poll() will set returncode to a default value,
-            # since waitpid() fails with ProcessLookupError.
-            self.poll()
-            if self.returncode is not None:
-                # Skip signalling a process that we know has already died.
-                return
-
-            # The race condition can still happen if the race condition
-            # described above happens between the returncode test
-            # and the kill() call.
-            try:
+            # Skip signalling a process that we know has already died.
+            if self.returncode is None:
                 os.kill(self.pid, sig)
-            except ProcessLookupError:
-                # Supress the race condition error; bpo-40550.
-                pass
 
         def terminate(self):
             """Terminate the process with SIGTERM
