@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/python3.7
+#!/usr/pkg/bin/python3.8
 """       xturtle-example-suite:
 
           xtx_kites_and_darts.py
@@ -137,13 +137,10 @@ def test(l=200, n=4, fun=sun, startpos=(0,0), th=2):
     goto(startpos)
     setheading(0)
     tiledict = {}
-    a = clock()
     tracer(0)
     fun(l, n)
-    b = clock()
     draw(l, n, th)
     tracer(1)
-    c = clock()
     nk = len([x for x in tiledict if tiledict[x]])
     nd = len([x for x in tiledict if not tiledict[x]])
     print("%d kites and %d darts = %d pieces." % (nk, nd, nk+nd))
